<?php
/**
 * Represents the view for the administration dashboard.
 *
 * This includes the header, options, and other information that should provide
 * The User Interface to the end user.
 *
 * @package   Wizart
 * @author    Wizart <nikolay.novosad@wizart.tech>
 * @license   GPL-2.0+
 * @link      https://www.wizart.tech/
 */
?>
<div id="wizart-settings" class="wrap">

    <?php if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    } ?>

    <?php
    $is_updated = get_option('wizart_updated_data');
    if ($is_updated) {
        echo '<div class="wizart-updated__message">Data updated successfully</div>';
        update_option('wizart_updated_data', false);
    }
    ?>

    <h2><?php echo esc_html(get_admin_page_title()); ?></h2>

    <form method="post" action="<?php echo esc_html(admin_url('admin-post.php')); ?>">
        <div class="options">
            <div class="wizart-notice">
                <p class="wizart-notice__message">Go to PIM Admin -> Configuration -> Web and copy API Token</p>
                <p>
                    <label><?php echo __('API Token', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_api_token" size="55" required="required"
                           placeholder="Please enter API Token"
                           value="<?php echo esc_attr((get_option('wizart_api_token'))); ?>"/>
                </p>
            </div>
            <div class="wizart-notice">
                <p class="wizart-notice__message">
                    <b>Please Note:</b> By ticking this box, you are choosing an iframe integration, which is an alternative to our general script integration. Please choose an iframe integration only when the entry point buttons were not added to the Product and Category pages after completing the integration steps described below.
                    <br/><br/>
                    In case you have any questions, please contact <a href="mailto:support@wizart.ai">support@wizart.ai</a>
                </p>
                <p>
                    <input type="checkbox" value="iframe" name="wizart_integration_method"
                           <?php if (get_option('wizart_integration_method') === 'iframe'): ?>checked<?php endif; ?> />
                    <label><?php echo __('Iframe Method', 'wizart'); ?></label>
                </p>
            </div>
            <h2>Button Setting</h2>
            <fieldset>
                <legend><b><?php echo __('Homepage', 'wizart'); ?></b></legend>
                <p>
                    <label><?php echo __('Button Text', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_button_text"
                           placeholder="Default: Try this article!"
                           value="<?php echo esc_attr((get_option('wizart_homepage_button_text'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Custom Class', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_custom_class"
                           placeholder="If necessary, add a class to style the button"
                           value="<?php echo esc_attr((get_option('wizart_homepage_custom_class'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_data_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert a button where you want."
                           value="<?php echo esc_attr((get_option('wizart_homepage_data_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert Element Position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_data_insert_element_position"
                           placeholder="Values: append, before, after. Default value: append"
                           value="<?php echo esc_attr((get_option('wizart_homepage_data_insert_element_position'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Iframe Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_data_iframe_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert the fitting room where you want."
                           value="<?php echo esc_attr((get_option('wizart_homepage_data_iframe_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert iframe element position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_homepage_data_insert_iframe_element_position"
                           placeholder="Values: append, before, after. Default value: append."
                           value="<?php echo esc_attr((get_option('wizart_homepage_data_insert_iframe_element_position'))); ?>"/>
                </p>
            </fieldset>
            <fieldset>
                <legend><b><?php echo __('Category page', 'wizart'); ?></b></legend>
                <p>
                    <label><?php echo __('Button Text', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_button_text"
                           placeholder="Default: Try it in your room in one click!"
                           value="<?php echo esc_attr((get_option('wizart_category_button_text'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Width Size (px,%)', 'wizart'); ?>:</label>
                    <input type="text" min="50" name="wizart_category_width"
                           placeholder="Default: 500px"
                           value="<?php echo esc_attr((get_option('wizart_category_width'))); ?>"/>

                </p>
                <p>
                    <label><?php echo __('Height Size (px,%)', 'wizart'); ?>:</label>
                    <input type="text" min="25" name="wizart_category_height"
                           placeholder="Default: 60px"
                           value="<?php echo esc_attr((get_option('wizart_category_height'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Custom Class', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_custom_class"
                           placeholder="If necessary, add a class to style the button"
                           value="<?php echo esc_attr((get_option('wizart_category_custom_class'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_data_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert a button where you want."
                           value="<?php echo esc_attr((get_option('wizart_category_data_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert Element Position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_data_insert_element_position"
                           placeholder="Values: append, before, after. Default value: append"
                           value="<?php echo esc_attr((get_option('wizart_category_data_insert_element_position'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Iframe Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_data_iframe_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert the fitting room where you want."
                           value="<?php echo esc_attr((get_option('wizart_category_data_iframe_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert iframe element position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_category_data_insert_iframe_element_position"
                           placeholder="Values: append, before, after. Default value: append."
                           value="<?php echo esc_attr((get_option('wizart_category_data_insert_iframe_element_position'))); ?>"/>
                </p>
            </fieldset>
            <fieldset>
                <legend><b><?php echo __('Single product page', 'wizart'); ?></b></legend>
                <p>
                    <label><?php echo __('Button Text', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_button_text"
                           placeholder="Default: Try it in your room in one click!"
                           value="<?php echo esc_attr((get_option('wizart_single_button_text'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Width Size (px,%)', 'wizart'); ?>:</label>
                    <input type="text" min="50" name="wizart_single_width"
                           placeholder="Default: 500px"
                           value="<?php echo esc_attr((get_option('wizart_single_width'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Height Size (px,%)', 'wizart'); ?>:</label>
                    <input type="text" min="25" name="wizart_single_height"
                           placeholder="Default: 60px"
                           value="<?php echo esc_attr((get_option('wizart_single_height'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Custom Class', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_custom_class"
                           placeholder="If necessary, add a class to style the button"
                           value="<?php echo esc_attr((get_option('wizart_single_custom_class'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_data_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert a button where you want."
                           value="<?php echo esc_attr((get_option('wizart_single_data_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert Element Position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_data_insert_element_position"
                           placeholder="Values: append, before, after."
                           value="<?php echo esc_attr((get_option('wizart_single_data_insert_element_position'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Iframe Element Selector', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_data_iframe_element_selector"
                           placeholder="A CSS selector to select an element on the page to insert the fitting room where you want."
                           value="<?php echo esc_attr((get_option('wizart_single_data_iframe_element_selector'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Insert iframe element position', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_single_data_insert_iframe_element_position"
                           placeholder="Values: append, before, after."
                           value="<?php echo esc_attr((get_option('wizart_single_data_insert_iframe_element_position'))); ?>"/>
                </p>
            </fieldset>
            <h2>Additional Settings</h2>
            <fieldset>
                <p>
                    <label><?php echo __('Life time (in seconds)', 'wizart'); ?>:</label>
                    <input type="number" name="wizart_cache_lifetime"
                           value="<?php echo esc_attr((get_option('wizart_cache_lifetime'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Context', 'wizart'); ?>:</label>
                    <input type="text" name="wizart_context"
                           value="<?php echo esc_attr((get_option('wizart_context'))); ?>"/>
                </p>
                <p>
                    <label><?php echo __('Disable uploading photos', 'wizart'); ?>:</label>
                    <input type="checkbox" value="1" name="wizart_is_disable_upload_image"
                           <?php if (get_option('wizart_is_disable_upload_image') === '1'): ?>checked<?php endif; ?> />
                </p>
            </fieldset>
        </div>

        <?php
        wp_nonce_field('wizart_settings_save', 'wizart_form');
        submit_button();
        ?>

    </form>
</div>