<?php

final class WizartCache
{
    const DEFAULT_CACHE_LIFETIME = 43200;
    const CACHE_OPTION = 'wizart-cache';
    const CACHED_TIME_OPTION = 'time';

    public static $instance = null;

    protected function __construct()
    {
    }

    /**
     * Add to cache
     *
     * @since 1.0.3
     * @param mixed $value
     * @param string $key
     * @param int $lifetime
     */
    public function add(string $key, $value, int $lifetime = self::DEFAULT_CACHE_LIFETIME)
    {
        update_option($this->getCacheOptionName($key), $value);
        update_option($this->getCachedTimeOptionName($key), \time() + $lifetime);
    }

    /**
     * Get from cache
     *
     * @since 1.0.3
     * @param string $key
     * @return false|mixed|void|null
     */
    public function get(string $key)
    {
        $result = null;
        if ($this->isCacheExpired($key)) {
            delete_option($this->getCacheOptionName($key));

            return null;
        }

        return get_option($this->getCacheOptionName($key), null);
    }

    /**
     * Clear cache
     *
     * @since 1.0.3
     */
    public function clear()
    {
        global $wpdb;

        $wpdb->query("DELETE FROM $wpdb->options WHERE option_name LIKE '%" . self::CACHE_OPTION . "%'");
    }

    /**
     * @param string $key
     * @since 1.0.3
     * @return bool
     */
    protected function isCacheExpired(string $key)
    {
        $option = $this->getCachedTimeOptionName($key);
        $cacheTime = get_option($option) ?: 0;
        if (\time() > $cacheTime) {
            delete_option($option);

            return true;
        }

        return false;
    }

    /**
     * Create instantiate
     *
     * @since 1.0.3
     * @return WizartCache
     */
    static public function instantiate()
    {
        if (null === self::$instance) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    /**
     * Get cache option name
     *
     * @since 1.0.3
     * @param string $key
     * @return string
     */
    protected function getCacheOptionName(string $key)
    {
        return sprintf('%s-%s', self::CACHE_OPTION, $key);
    }

    /**
     * Get cache time option name
     *
     * @since 1.0.3
     * @param string $key
     * @return string
     */
    protected function getCachedTimeOptionName(string $key)
    {
        return sprintf('%s-%s-%s', self::CACHE_OPTION, self::CACHED_TIME_OPTION, $key);
    }
}
